Data Model Schema
This page is generated from the hyperledger-iroha/iroha i23-features branch. pnpm get-snippets reads docs/source/references/schema.json from that source when it is available. If that snapshot is empty, regenerate this page from the same branch with the snippet tooling after the upstream schema generator succeeds.
WARNING
The Iroha data-model schema snapshot is currently unavailable. https://raw.githubusercontent.com/hyperledger-iroha/iroha/i23-features/docs/source/references/schema.json is empty, and kagami advanced schema could not generate a replacement from the configured Iroha source checkout.
Refresh this page with pnpm get-snippets after the upstream schema generator succeeds. Set IROHA_SOURCE_DIR if you need to generate the schema from a local checkout.
IROHA_SOURCE_DIR is not configured.